@@ -3,5 +3,5 @@
 
 __author__ = 'Jorge Samper Gonzalez'
 __email__ = 'jsampergonzalez@gmail.com'
-__version__ = '0.1.0'
-__all__ = ["interpreter"]
\ No newline at end of file
+__version__ = '1.0.0'
+__all__ = ["interpreter_parse", "syntax_highlighter"]
